@@ -64,7 +64,6 @@ terrain <- function(x, opt='slope', unit='radians', neighbors=8, filename='', ..
 
 	rs <- as.double(res(out))
 	un <- as.integer(1)
-	y <- 0;
 	lonlat <- FALSE
 	if ('slope' %in% opt | 'aspect' %in% opt | 'flowdir' %in% opt) {
 		stopifnot(is.character(unit))
@@ -78,13 +77,17 @@ terrain <- function(x, opt='slope', unit='radians', neighbors=8, filename='', ..
 		lonlat <- isLonLat(out)
 		if (lonlat) {		
 			rs[2] <- pointDistance(cbind(0,0), cbind(0, rs[2]), longlat=TRUE)
-			y <- yFromRow(x, 1:nrow(x))
 		}
 	}
 	lonlat <- as.integer(lonlat)
 	
 	
 	if (canProcessInMemory(out)) {
+		if (lonlat) {
+			y <- yFromRow(x, 1:nrow(x))
+		} else {
+			y <- 0
+		}
 		v <- .Call('terrain', as.double(values(x)), as.integer(dim(out)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
 		out <- setValues(out, v)
 		if (filename  != '') {
@@ -100,11 +103,14 @@ terrain <- function(x, opt='slope', unit='radians', neighbors=8, filename='', ..
 		nc <- ncol(out)
 		buf <- 1:nc
 		v <- getValues(x, row=1, nrows=tr$nrows[1]+1)
+		y <- 0
+		if (lonlat) { y <- yFromRow(out, 1:(tr$nrows[1]+1)) }
 		v <- .Call('terrain', as.double(v), as.integer(c(tr$nrows[1]+1, nc)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
 		out <- writeValues(out, matrix(v, ncol=nl), 1)
 		pbStep(pb, 1)
 		for (i in 2:(tr$n-1)) {
 			v <- getValues(x, row=tr$row[i]-1, nrows=tr$nrows[i]+2)
+			if (lonlat) { y <- yFromRow(out, (tr$row[i]-1) : (tr$row[i]+tr$nrows[i])) }
 			v <- .Call('terrain', as.double(v), as.integer(c(tr$nrows[i]+2, nc)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
 			v <- matrix(v, ncol=nl)[-buf,]
 			out <- writeValues(out, v, tr$row[i])
@@ -112,6 +118,7 @@ terrain <- function(x, opt='slope', unit='radians', neighbors=8, filename='', ..
 		}
 		i <- tr$n
 		v <- getValues(x, row=tr$row[i]-1, nrows=tr$nrows[i]+1)
+		if (lonlat) { y <- yFromRow(out, (tr$row[i]-1) : (tr$row[i]+tr$nrows[i]-1)) }
 		v <- .Call('terrain', as.double(v), as.integer(c(tr$nrows[i]+1, nc)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
 		v <- matrix(v, ncol=nl)[-buf,]
 		out <- writeValues(out, v, tr$row[i])
